.modules-list{
    width: 100%;
    float: left;
    margin-top: 25px;
}
.container-helper p{
    font-size: 14px;
}
.container-helper h1{
    padding: 30px 0;
    font-weight: bold;
}
.container-helper h2, .container-helper h3{
    font-size: 25px;
    text-decoration: underline;
    padding: 30px 0;
}
.container-helper h2:nth-child(2){
    padding-top: 0;
}
.container-helper .tab-content{
    padding: 0 60px;
}
.container-helper pre{
    background: #f5f5f5;
    border: 1px solid #ccc;
    border-radius: 3px;
    overflow-x: auto;
    padding: 5px 10px;
    word-wrap: normal;
    margin: 10px 0;
}
.container-helper ol, .container-helper ul{
    padding-left: 40px;
}